"use strict";
const common_vendor = require("../../common/vendor.js");
require("../../store/index.js");
const api_login = require("../../api/login.js");
const api_my = require("../../api/my.js");
const store_modules_member = require("../../store/modules/member.js");
require("../../utils/request.js");
if (!Array) {
  const _easycom_uni_icons2 = common_vendor.resolveComponent("uni-icons");
  _easycom_uni_icons2();
}
const _easycom_uni_icons = () => "../../uni_modules/uni-icons/components/uni-icons/uni-icons.js";
if (!Math) {
  _easycom_uni_icons();
}
const _sfc_main = /* @__PURE__ */ common_vendor.defineComponent({
  __name: "index",
  setup(__props) {
    const memberStore = store_modules_member.useMemberStore();
    const userInfo = common_vendor.ref({
      balance: 0,
      headimg: "",
      headimg_id: "",
      id: 0,
      invitation_qrcode: "",
      invitation_uid: 0,
      nickname: "",
      poster_img: "",
      realname: "",
      realphone: "",
      vip_title: " ",
      wxskqrcode: "",
      wxskqrcode_id: "0"
    });
    const isNewUser = common_vendor.ref(false);
    const hasClickedLogin = common_vendor.ref(false);
    const handleNicknameChange = (e) => {
      userInfo.value.nickname = e.detail.value;
    };
    const handleUploadAvatar = async (e) => {
      common_vendor.index.showLoading({
        title: "上传中"
      });
      const avatarPath = e.detail.avatarUrl;
      common_vendor.index.uploadFile({
        url: "https://buildgroup.ccjjj.com/api/Uploadfile/uploadimgfile",
        name: "imgfile",
        filePath: avatarPath,
        success: (res) => {
          const data = JSON.parse(res.data);
          if (res.statusCode === 200) {
            userInfo.value.headimg_id = data.result.img_id || "";
            userInfo.value.headimg = data.result.img_url || "";
          } else {
            common_vendor.index.showToast({ icon: "none", title: data.msg });
          }
        }
      });
      common_vendor.index.hideLoading();
    };
    const checkUserStatus = async () => {
      try {
        const existingToken = common_vendor.index.getStorageSync("token");
        if (existingToken) {
          await queryUserInfo();
          return;
        }
        const res1 = await common_vendor.wx$1.login();
        if (res1.code) {
          const res2 = await api_login.loginCodeCheck({ js_code: res1.code });
          if (res2.code === 200) {
            if (res2.msg.trim() === "绑定成功") {
              isNewUser.value = true;
              common_vendor.index.setStorageSync("tempToken", res2.result.user_token);
            } else if (res2.msg.trim() === "登录成功") {
              isNewUser.value = false;
              isCheck.value = true;
              common_vendor.index.setStorageSync("token", res2.result.user_token);
              await queryUserInfo();
            }
          }
        }
      } catch (error) {
        console.error("检查用户状态失败:", error);
        common_vendor.index.showToast({
          title: "登录失败，请重试",
          icon: "none"
        });
      }
    };
    const queryUserInfo = async () => {
      try {
        const userInfoRes = await api_my.getUserInfo();
        if (userInfoRes.code === 200) {
          memberStore.setProfile(userInfoRes.result);
          Object.assign(userInfo.value, userInfoRes.result);
        }
      } catch (error) {
        console.error("获取用户信息失败:", error);
        common_vendor.index.showToast({
          title: "登录失败，请重试",
          icon: "none"
        });
      }
    };
    const handleOldUserLogin = async () => {
      if (!isCheck.value) {
        common_vendor.index.showToast({
          title: "请勾选隐私协议",
          icon: "none"
        });
        return;
      }
      try {
        const originalUserInfo = memberStore.profile;
        const hasInfoChanged = userInfo.value.headimg_id !== originalUserInfo.headimg_id || userInfo.value.nickname !== originalUserInfo.nickname;
        if (hasInfoChanged) {
          const form = {
            headimg: userInfo.value.headimg_id || "635",
            nickname: userInfo.value.nickname,
            realname: "",
            realphone: "",
            wxskqrcode: ""
          };
          const updateRes = await api_login.setUserInfo(form);
          if (updateRes.code !== 200) {
            common_vendor.index.showToast({
              icon: "error",
              title: updateRes.msg || "更新用户信息失败"
            });
            return;
          }
        }
        hasClickedLogin.value = true;
        common_vendor.index.showToast({
          title: "登录成功",
          icon: "none"
        });
        common_vendor.index.switchTab({
          url: "/pages/index/index"
        });
      } catch (error) {
        console.error("登录失败:", error);
        common_vendor.index.showToast({
          title: "登录失败，请重试",
          icon: "none"
        });
      }
    };
    const handleUserProfile = async () => {
      if (!isCheck.value) {
        common_vendor.index.showToast({ icon: "none", title: "请勾选隐私协议" });
        return;
      }
      const res1 = await common_vendor.wx$1.login();
      console.log(res1);
      const res2 = await api_login.loginCodeCheck({ js_code: res1.code });
      if (res2.code == 200) {
        memberStore.setToken(res2.result.user_token);
        common_vendor.index.setStorage({
          key: "token",
          data: res2.result.user_token
        });
        updateUserInfo();
      }
    };
    common_vendor.onLoad(() => {
      checkUserStatus();
    });
    common_vendor.onUnload(() => {
      if (!isNewUser.value && !hasClickedLogin.value) {
        common_vendor.index.removeStorageSync("token");
        common_vendor.index.removeStorageSync("userInfo");
        memberStore.clearProfile();
        console.log("清除了登录信息");
      }
    });
    const updateUserInfo = async () => {
      var _a;
      const form = common_vendor.ref({
        headimg: userInfo.value.headimg_id !== "" && userInfo.value.headimg_id ? (_a = userInfo.value) == null ? void 0 : _a.headimg_id : "635",
        nickname: userInfo.value.nickname,
        // invitation_uid: '',
        realname: "",
        realphone: "",
        wxskqrcode: ""
      });
      console.log("邀请用户注册id", memberStore.invitation_uid);
      if (memberStore.invitation_uid) {
        form.value["invitation_uid"] = memberStore.invitation_uid;
      }
      const res3 = await api_login.setUserInfo(form.value);
      if (res3.code == 200) {
        memberStore.setProfile(userInfo.value);
        const pages = getCurrentPages();
        if (pages.length > 1) {
          setTimeout(() => {
            common_vendor.index.navigateBack();
          }, 400);
        } else {
          common_vendor.index.switchTab({
            url: "/pages/index/index"
          });
        }
      } else {
        common_vendor.index.showToast({ icon: "error", title: res3.msg });
      }
    };
    const isCheck = common_vendor.ref(false);
    const onCheckboxChange = (val) => {
      isCheck.value = val;
    };
    return (_ctx, _cache) => {
      return common_vendor.e({
        a: userInfo.value.headimg && userInfo.value.headimg != ""
      }, userInfo.value.headimg && userInfo.value.headimg != "" ? {
        b: userInfo.value.headimg
      } : {
        c: common_vendor.p({
          type: "person-filled",
          color: "#E2E2E2",
          size: "55"
        })
      }, {
        d: common_vendor.o(handleUploadAvatar),
        e: common_vendor.o([($event) => userInfo.value.nickname = $event.detail.value, handleNicknameChange]),
        f: common_vendor.o(handleNicknameChange),
        g: userInfo.value.nickname,
        h: common_vendor.p({
          type: "info",
          size: "15",
          color: "#AFAFAF"
        }),
        i: isNewUser.value
      }, isNewUser.value ? {
        j: common_vendor.o(handleUserProfile)
      } : {
        k: common_vendor.o(handleOldUserLogin)
      }, {
        l: !isCheck.value
      }, !isCheck.value ? {
        m: common_vendor.o(($event) => onCheckboxChange(true)),
        n: common_vendor.p({
          type: "circle",
          size: "20",
          color: "#757575"
        })
      } : {}, {
        o: isCheck.value
      }, isCheck.value ? {
        p: common_vendor.o(($event) => onCheckboxChange(false)),
        q: common_vendor.p({
          type: "checkbox-filled",
          size: "20",
          color: "#0374FE"
        })
      } : {}, {
        r: common_vendor.t("《"),
        s: common_vendor.t("》"),
        t: common_vendor.t("《"),
        v: common_vendor.t("》")
      });
    };
  }
});
const MiniProgramPage = /* @__PURE__ */ common_vendor._export_sfc(_sfc_main, [["__file", "/Users/mac/Desktop/dazi/pages/login/index.vue"]]);
wx.createPage(MiniProgramPage);
